# googledevices

[![Build Status][travis_status]][travis]
[![PyPI version][pypi_badge]][pypi]

_Get information from, and control various Google devices._

## Install

```bash
pip install googledevices
```

For documentation please visit the [documentation website][docs].  
The documentation _might_ not be "good" but it's there.

[docs]: https://ludeeus.github.io/googledevices/
[travis]: https://travis-ci.com/ludeeus/googledevices
[travis_status]: https://travis-ci.com/ludeeus/googledevices.svg?branch=master
[pypi]:https://pypi.org/project/googledevices/
[pypi_badge]: https://badge.fury.io/py/googledevices.svg
